#!/bin/bash
#
# Last update: 2022.2.22
# URL : https://openresty.org/en/
# 2019.3.26 將 openresty 443 相關設定取消使用，等解決SSL憑證抓取異常問題，再重新開放
# 2022.2.22 更新版本 1.17.8.2 to 1.19.9.1 & openssl-1.1.1j to openssl-1.1.1m

COLOR_GREEN='\e[0;32m';
COLOR_REST='\e[0m'
echo -e "${COLOR_GREEN}!! Install Openresty !!${COLOR_REST}"

yum install unzip git pcre-devel -y

echo -e "${COLOR_GREEN}!! Changing Apache Port !!${COLOR_REST}"
# 更改 http 與 https 對應的 port 為 28080 與 28443
whmapi1 set_tweaksetting key=apache_port value=0.0.0.0:28080
#whmapi1 set_tweaksetting key=apache_ssl_port value=0.0.0.0:28443
echo '!! Wait for 10 seconds to take effect !!'
sleep 10

# 下載並安裝 Openresty 主程式
cd /usr/local/src/
rm -rf nginx*
rm -rf ngx_openresty*
rm -rf openresty-*
rm -rf openssl-*
wget https://www.openssl.org/source/openssl-1.1.1m.tar.gz --no-check-certificate
tar zxf openssl-1.1.1m.tar.gz
wget https://openresty.org/download/openresty-1.19.9.1.tar.gz
tar zxf openresty-1.19.9.1.tar.gz
cd openresty-1.19.9.1
./configure --prefix=/usr/local/openresty --with-http_secure_link_module --with-http_stub_status_module --with-http_realip_module --with-ipv6 --with-http_ssl_module --with-openssl=../openssl-1.1.1m --with-http_v2_module --with-http_secure_link_module --without-luajit-gc64
gmake
gmake install

# 安裝 resty-http
cd /usr/local/src
rm -rf lua-resty-http-master*
git clone https://github.com/pintsized/lua-resty-http.git
cp lua-resty-http/lib/resty/*.lua /usr/local/openresty/lualib/resty/

# 更改 nginx.conf 設定
cd /opt
git clone git@git.twnoc.net:twnoc/openresty-lua-release.git
cd /usr/local/openresty/nginx/conf
mv nginx.conf nginx.conf_bak
#ln -s /opt/openresty-lua-release/nginx.conf
cp /opt/cpinst/cpinst/config/nginx.conf /usr/local/openresty/nginx/conf/nginx.conf
ln -s /opt/openresty-lua-release/ddos.conf
mkdir /usr/local/openresty/nginx/lua
mkdir /usr/local/openresty/nginx/ssl
cd /usr/local/openresty/nginx/lua
ln -s /opt/openresty-lua-release/init.luac
ln -s /opt/openresty-lua-release/ssl.luac
ln -s /opt/openresty-lua-release/status.luac
ln -s /opt/openresty-lua-release/retry502.luac
cd /usr/local/openresty/nginx/ssl
ln -s /opt/openresty-lua-release/selfsign.key
ln -s /opt/openresty-lua-release/selfsign.pem
ln -s /opt/openresty-lua-release/dhparam.pem

echo -e "${COLOR_GREEN}!! Restart Apache !!${COLOR_REST}"
# 重啟 httpd 服務
/scripts/restartsrv_httpd
sleep 2
/scripts/restartsrv_httpd

# 產生 API Token
/opt/openresty-lua-release/GenerateAPItoken.sh

# 新增 init 並啟用服務
if [ ! -e /usr/bin/systemctl ]; then
	cd /opt
	git clone git@git.twnoc.net:twnoc/cpinst.git
	cp /opt/cpinst/cpinst/config/openresty_init /etc/init.d/nginx
	chmod 0750 /etc/init.d/nginx
	/etc/init.d/nginx stop
	/etc/init.d/nginx start
	/sbin/chkconfig nginx on
else
	# CentOS 7
	cd /opt
	git clone git@git.twnoc.net:twnoc/cpinst.git
	cp /opt/cpinst/cpinst/config/openresty_service /usr/lib/systemd/system/openresty.service
	systemctl enable openresty.service
	systemctl start openresty.service
fi

echo -e "${COLOR_GREEN}!! Clean up !!${COLOR_REST}"
# 刪除暫存安裝檔案
rm -rf /usr/local/src/nginx*
rm -rf /usr/local/src/ngx_openresty*
rm -rf /usr/local/src/openresty*
rm -rf /usr/local/src/lua-resty-http-master*

# 調整防火牆設定
#if [ -e /etc/csf/csf.pignore ]; then
#	if ! grep -q openresty /etc/csf/csf.pignore; then
#	    echo 'exe:/usr/local/openresty/nginx/sbin/nginx' >> /etc/csf/csf.pignore
#	fi
#fi
#echo "iptables -I OUTPUT -d 127.0.0.1 -p tcp --dport 6379 --syn -j DROP" >> /etc/csf/csfpost.sh
#echo "iptables -I OUTPUT -d 127.0.0.1 -p tcp --dport 6379 --syn -m owner --uid-owner nobody -j ACCEPT" >> /etc/csf/csfpost.sh
#echo "iptables -I OUTPUT -d 127.0.0.1 -p tcp --dport 6379 --syn -m owner --uid-owner nagios -j ACCEPT" >> /etc/csf/csfpost.sh
#echo "iptables -I OUTPUT -d 127.0.0.1 -p tcp --dport 6379 --syn -m owner --uid-owner root -j ACCEPT" >> /etc/csf/csfpost.sh
#systemctl restart csf

echo -e "${COLOR_GREEN}!! Done !!${COLOR_REST}"
echo -e "==========================="
netstat -tulnp | grep nginx
echo -e "==========================="
netstat -tulnp | grep httpd

